@@ -12,8 +12,9 @@ has [qw(backlog silent)];
 has inactivity_timeout => sub { $ENV{MOJO_INACTIVITY_TIMEOUT} // 15 };
 has ioloop => sub { Mojo::IOLoop->singleton };
 has listen => sub { [split ',', $ENV{MOJO_LISTEN} || 'http://*:3000'] };
-has max_clients  => 1000;
-has max_requests => 25;
+has max_clients   => 1000;
+has max_requests  => 25;
+has reverse_proxy => sub { $ENV{MOJO_REVERSE_PROXY} };
 
 sub DESTROY {
   my $self = shift;
@@ -67,6 +68,7 @@ sub _build_tx {
   my $handle = $self->ioloop->stream($id)->handle;
   $tx->local_address($handle->sockhost)->local_port($handle->sockport);
   $tx->remote_address($handle->peerhost)->remote_port($handle->peerport);
+  $tx->req->reverse_proxy(1) if $self->reverse_proxy;
   $tx->req->url->base->scheme('https') if $c->{tls};
 
   # Handle upgrades and requests
@@ -409,6 +411,14 @@ Maximum number of concurrent client connections, defaults to C<1000>.
 
 Maximum number of keep-alive requests per connection, defaults to C<25>.
 
+=head2 reverse_proxy
+
+  my $bool = $daemon->reverse_proxy;
+  $daemon  = $daemon->reverse_proxy($bool);
+
+This server operates behind a reverse proxy, defaults to the value of the
+C<MOJO_REVERSE_PROXY> environment variable.
+
 =head2 silent
 
   my $bool = $daemon->silent;
