@@ -10,29 +10,50 @@ use Mojo::Server::Prefork;
 use Mojo::Util 'steady_time';
 use Scalar::Util 'weaken';
 
+has prefork => sub { Mojo::Server::Prefork->new };
+has upgrade_timeout => 60;
+
+sub configure {
+  my ($self, $name) = @_;
+
+  # Hypnotoad settings
+  my $prefork = $self->prefork;
+  my $c = $prefork->app->config($name) || {};
+  $c->{listen} ||= ['http://*:8080'];
+  $self->upgrade_timeout($c->{upgrade_timeout}) if $c->{upgrade_timeout};
+
+  # Prefork settings
+  $prefork->reverse_proxy($c->{proxy}) if defined $c->{proxy};
+  $prefork->max_clients($c->{clients}) if $c->{clients};
+  $prefork->max_requests($c->{keep_alive_requests})
+    if $c->{keep_alive_requests};
+  defined $c->{$_} and $prefork->$_($c->{$_})
+    for qw(accept_interval accepts backlog graceful_timeout group),
+    qw(heartbeat_interval heartbeat_timeout inactivity_timeout listen),
+    qw(lock_file lock_timeout multi_accept pid_file user workers);
+}
+
 sub run {
-  my ($self, $path) = @_;
+  my ($self, $app) = @_;
 
   # No Windows support
   _exit('Hypnotoad not available for Windows.') if $^O eq 'MSWin32';
 
-  # Remember application for later
-  $ENV{HYPNOTOAD_APP} ||= abs_path $path;
+  # Remember executable and application for later
+  $ENV{HYPNOTOAD_EXE} ||= $0;
+  $0 = $ENV{HYPNOTOAD_APP} ||= abs_path $app;
 
   # This is a production server
   $ENV{MOJO_MODE} ||= 'production';
 
-  # Remember executable for later
-  $ENV{HYPNOTOAD_EXE} ||= $0;
-  $0 = $ENV{HYPNOTOAD_APP};
-
-  # Clean start
+  # Clean start (to make sure everything works)
   die "Can't exec: $!" if !$ENV{HYPNOTOAD_REV}++ && !exec $ENV{HYPNOTOAD_EXE};
 
   # Preload application and configure server
-  my $prefork = $self->{prefork} = Mojo::Server::Prefork->new;
-  my $app = $prefork->load_app($ENV{HYPNOTOAD_APP});
-  $self->_config($app);
+  my $prefork = $self->prefork;
+  $prefork->load_app($app)->config->{hypnotoad}{pid_file}
+    //= catfile dirname($ENV{HYPNOTOAD_APP}), 'hypnotoad.pid';
+  $self->configure('hypnotoad');
   weaken $self;
   $prefork->on(wait   => sub { $self->_manage });
   $prefork->on(reap   => sub { $self->_reap(pop) });
@@ -56,34 +77,13 @@ sub run {
   $prefork->run;
 }
 
-sub _config {
-  my ($self, $app) = @_;
-
-  # Hypnotoad settings
-  my $c = $app->config('hypnotoad') || {};
-  $self->{upgrade_timeout} = $c->{upgrade_timeout} || 60;
-
-  # Prefork settings
-  $ENV{MOJO_REVERSE_PROXY} = $c->{proxy} if defined $c->{proxy};
-  my $prefork = $self->{prefork}->listen($c->{listen} || ['http://*:8080']);
-  my $file = catfile dirname($ENV{HYPNOTOAD_APP}), 'hypnotoad.pid';
-  $prefork->pid_file($c->{pid_file} || $file);
-  $prefork->max_clients($c->{clients}) if $c->{clients};
-  $prefork->max_requests($c->{keep_alive_requests})
-    if $c->{keep_alive_requests};
-  defined $c->{$_} and $prefork->$_($c->{$_})
-    for qw(accept_interval accepts backlog graceful_timeout group),
-    qw(heartbeat_interval heartbeat_timeout inactivity_timeout lock_file),
-    qw(lock_timeout multi_accept user workers);
-}
-
 sub _exit { say shift and exit 0 }
 
 sub _hot_deploy {
   my $self = shift;
 
   # Make sure server is running
-  return unless my $pid = $self->{prefork}->check_pid;
+  return unless my $pid = $self->prefork->check_pid;
 
   # Start hot deployment
   kill 'USR2', $pid;
@@ -94,7 +94,7 @@ sub _manage {
   my $self = shift;
 
   # Upgraded
-  my $log = $self->{prefork}->app->log;
+  my $log = $self->prefork->app->log;
   if ($ENV{HYPNOTOAD_PID} && $ENV{HYPNOTOAD_PID} ne $$) {
     $log->info("Upgrade successful, stopping $ENV{HYPNOTOAD_PID}.");
     kill 'QUIT', $ENV{HYPNOTOAD_PID};
@@ -113,7 +113,7 @@ sub _manage {
 
     # Timeout
     kill 'KILL', $self->{new}
-      if $self->{upgrade} + $self->{upgrade_timeout} <= steady_time;
+      if $self->{upgrade} + $self->upgrade_timeout <= steady_time;
   }
 }
 
@@ -122,13 +122,13 @@ sub _reap {
 
   # Clean up failed upgrade
   return unless ($self->{new} || '') eq $pid;
-  $self->{prefork}->app->log->info('Zero downtime software upgrade failed.');
+  $self->prefork->app->log->info('Zero downtime software upgrade failed.');
   delete @$self{qw(new upgrade)};
 }
 
 sub _stop {
   _exit('Hypnotoad server not running.')
-    unless my $pid = shift->{prefork}->check_pid;
+    unless my $pid = shift->prefork->check_pid;
   kill 'QUIT', $pid;
   _exit("Stopping Hypnotoad server $pid gracefully.");
 }
@@ -145,8 +145,8 @@ Mojo::Server::Hypnotoad - ALL GLORY TO THE HYPNOTOAD!
 
   use Mojo::Server::Hypnotoad;
 
-  my $toad = Mojo::Server::Hypnotoad->new;
-  $toad->run('/home/sri/myapp.pl');
+  my $hypnotoad = Mojo::Server::Hypnotoad->new;
+  $hypnotoad->run('/home/sri/myapp.pl');
 
 =head1 DESCRIPTION
 
@@ -379,14 +379,39 @@ worker processes per CPU core for applications that perform mostly
 non-blocking operations, blocking operations often require more and benefit
 from decreasing the number of concurrent L</"clients"> (often as low as C<1>).
 
+=head1 ATTRIBUTES
+
+L<Mojo::Server::Hypnotoad> implements the following attributes.
+
+=head2 prefork
+
+  my $prefork = $hypnotoad->prefork;
+  $hypnotoad  = $hypnotoad->prefork(Mojo::Server::Prefork->new);
+
+L<Mojo::Server::Prefork> object this server manages.
+
+=head1 upgrade_timeout
+
+  my $timeout = $hypnotoad->upgrade_timeout;
+  $hypnotoad  = $hypnotoad->upgrade_timeout(15);
+
+Maximum amount of time in seconds a zero downtime software upgrade may take
+before getting canceled, defaults to C<60>.
+
 =head1 METHODS
 
 L<Mojo::Server::Hypnotoad> inherits all methods from L<Mojo::Base> and
 implements the following new ones.
 
+=head2 configure
+
+  $hypnotoad->configure('hypnotoad');
+
+Configure server from application settings.
+
 =head2 run
 
-  $toad->run('script/myapp');
+  $hypnotoad->run('script/myapp');
 
 Run server for application.
 
